You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@celeborn.apache.org by "FMX (via GitHub)" <gi...@apache.org> on 2026/01/04 02:41:47 UTC

Re: [PR] [CELEBORN-2241] Memory swap instead of memory copy [celeborn]

FMX commented on PR #3572:
URL: https://github.com/apache/celeborn/pull/3572#issuecomment-3707555594

   
   SortBasedShuffleWriter | HashBasedShuffleWriter
   -- | --
   Before | 615.44W ms | 502.31W ms
   After | 442.47W ms | 434.77W ms
   
   You mean that the running time dropped from 6000 seconds to 4000 seconds, that's very impressive.


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: issues-unsubscribe@celeborn.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org